@@ -18,6 +18,7 @@ Our general approach to logging can be understood as:
    This appears to be good practice, as it allows us to associate what actions are taken
    with their result very effectively!
 """
+from mitosheet.user.schemas import UJ_MITOSHEET_TELEMETRY
 import platform
 import sys
 import subprocess
@@ -34,8 +35,22 @@ from mitosheet.user import (
 )
 from mitosheet.user import get_user_field, is_local_deployment, is_running_test, is_local_deployment
 from mitosheet._version import __version__
-from mitosheet.errors import get_recent_traceback_as_list
+from mitosheet.errors import get_recent_traceback, get_recent_traceback_as_list
 
+# We cache if logging is turned on to make sure we dont
+# make unecessary calls to read the user.json
+TELEMETRY_TURNED_ON = None
+
+def telemetry_turned_on():
+    """
+    Helper function that tells if you if logging is turned on or
+    turned off on the entire Mito instance
+    """
+    global TELEMETRY_TURNED_ON
+    if TELEMETRY_TURNED_ON is None:
+        TELEMETRY_TURNED_ON = get_user_field(UJ_MITOSHEET_TELEMETRY)
+    
+    return TELEMETRY_TURNED_ON
 
 # When we anonymize, we use some combination of these words
 # to construct new private words
@@ -147,6 +162,9 @@ def log(log_event, params=None, check_mitosheet_install=False):
     NOTE: check_mitosheet_install can be an expensive operation for some
     users, so we should try and minimize where / how we use it!
     """
+    if not telemetry_turned_on():
+        return
+
     if params is None:
         params = {}
     
@@ -239,6 +257,8 @@ def identify():
     Helper function for identifying a user. We just take
     their python version, mito version, and email.
     """
+    if not telemetry_turned_on():
+        return
 
     static_user_id = get_user_field(UJ_STATIC_USER_ID)
     user_email = get_user_field(UJ_USER_EMAIL)
@@ -287,13 +307,13 @@ def log_recent_error(log_event=None):
     )
 
 
-def log_event_processed(event, widget_state_container, failed=False, edit_error=None):
+def log_event_processed(event, steps_manager, failed=False, edit_error=None):
     """
     Helper function for logging when an event is processed
     by the widget state container. 
 
     Does it's best to fill in helpful meta-data for interpreting the event
-    including the state of the widget_state_container _after_ the step
+    including the state of the steps_manager _after_ the step
     was applied.
 
     NOTE: if processing the event fails, then failed should be True. If there was an
@@ -302,30 +322,37 @@ def log_event_processed(event, widget_state_container, failed=False, edit_error=
     """
     try:
         # First, we get all the params of the event, and append them with _params_
-        event_properties = {
-            'params_' + key: value for key, value in event.items()
-        }
+        if 'params' in event:
+            # If this is an edit event, then, we get the params from the params
+            # key all at once
+            event_properties = {
+                'params_' + key: value for key, value in event['params'].items()
+            }
+        else:
+            # Otherwise, we get the params from the highest level of the event 
+            event_properties = {
+                'params_' + key: value for key, value in event.items()
+            }
 
         # We also get some metadata about the widget state container at this state
-        wsc_properties = {
+        # NOTE: we keep this as underscored with wsc for backwards compatibility with
+        # our logs!
+        steps_manager_properties = {
             # NOTE: analysis name is the UUID that mito saves the analysis under
-            'wsc_analysis_name': widget_state_container.analysis_name,
+            'wsc_analysis_name': steps_manager.analysis_name,
             # NOTE: change this when code fixing this logic is merged in
-            'wsc_data_type_in_mito': str(widget_state_container.data_type_in_mito),
+            'wsc_data_type_in_mito': str(steps_manager.data_type_in_mito),
             'wsc_local': is_local_deployment(),
-            'wsc_curr_step_idx': widget_state_container.curr_step_idx,
-            'wsc_curr_step_type': widget_state_container.curr_step['step_type'],
+            'wsc_curr_step_idx': steps_manager.curr_step_idx,
+            'wsc_curr_step_type': steps_manager.curr_step.step_type,
         }
 
-        
-
         if event['type'] == 'replay_analysis_update' or event['type'] == 'save_analysis_update':
             # We log the steps, when the user saves or replays an analysis
-            wsc_properties['wsc_steps'] = [
-                step['step_type'] for step in widget_state_container.steps
+            steps_manager_properties['steps_manager_steps'] = [
+                step.step_type for step in steps_manager.steps
             ]
 
-
         # We also check there is an edit_error, and if there is, then we add the error logs
         if edit_error is not None:
             recent_traceback = get_recent_traceback_as_list()
@@ -361,7 +388,7 @@ def log_event_processed(event, widget_state_container, failed=False, edit_error=
             log_event, 
             dict(
                 **event_properties,
-                **wsc_properties,
+                **steps_manager_properties,
                 **error_properties
             )
         )
