@@ -14,6 +14,7 @@ in more detail in docs/README.md.
 
 NOTE: This file is alphabetical order!
 """
+from mitosheet.sheet_functions.types.utils import BOOLEAN_SERIES
 import pandas as pd
 import functools
 
@@ -23,7 +24,7 @@ from mitosheet.sheet_functions.sheet_function_utils import fill_series_list_to_m
 
 @handle_sheet_function_errors
 @filter_nans
-@convert_args_to_series_type('boolean_series', 'skip', ('default', True))
+@convert_args_to_series_type(BOOLEAN_SERIES, 'skip', ('default', True))
 def AND(*argv) -> pd.Series:
     """
     {
@@ -56,7 +57,7 @@ def AND(*argv) -> pd.Series:
 @fill_nans(0, False)
 @convert_arg_to_series_type(
     0,
-    'boolean_series', 
+    BOOLEAN_SERIES, 
     'error', 
     ('default', True)
 )
@@ -84,7 +85,7 @@ def BOOL(series) -> pd.Series:
 @filter_nans
 @convert_arg_to_series_type(
     0,
-    'boolean_series',
+    BOOLEAN_SERIES,
     'error',
     'error'
 )
@@ -136,7 +137,7 @@ def IF(condition, true_series, false_series) -> pd.Series:
 
 @handle_sheet_function_errors
 @filter_nans
-@convert_args_to_series_type('boolean_series', 'skip', ('default', True))
+@convert_args_to_series_type(BOOLEAN_SERIES, 'skip', ('default', True))
 def OR(*argv) -> pd.Series:
     """
     {
