@@ -12,7 +12,7 @@ from typing import Tuple, Union
 import pandas as pd
 import numpy as np
 
-from mitosheet.sheet_functions.types.utils import BOOLEAN_SERIES, DATETIME_SERIES, NUMBER_SERIES, STRING_SERIES, get_mito_type
+from mitosheet.sheet_functions.types.utils import BOOLEAN_SERIES, DATETIME_SERIES, NUMBER_SERIES, STRING_SERIES, TIMEDELTA_SERIES, get_mito_type
 
 
 def to_string_series(
@@ -33,6 +33,8 @@ def to_string_series(
         return unknown_object.astype('str')
     elif from_type == DATETIME_SERIES:
         return unknown_object.dt.strftime('%Y-%m-%d %X')
+    elif from_type == TIMEDELTA_SERIES:
+        return unknown_object.astype('str')
     elif from_type == NUMBER_SERIES:
         return unknown_object.astype('str')
     elif from_type == STRING_SERIES:
