@@ -192,5 +192,9 @@ def get_datetime_format(string_series):
             raise Exception("Non full conversion")
         return None
     except:
-        # Otherwise, we return true, as this is most likely the format
-        return '%m-%d-%Y'
\ No newline at end of file
+        # Otherwise, we manually figure out the format.
+        sample_string_datetime = string_series[string_series.first_valid_index()]
+        if "/" in sample_string_datetime: 
+            return '%m/%d/%Y'
+        else:
+            return '%m-%d-%Y'
\ No newline at end of file
