@@ -5,7 +5,8 @@
 # Distributed under the terms of the Modified BSD License.
 
 from copy import deepcopy
-from typing import List, OrderedDict
+from collections import OrderedDict
+from typing import List
 import pandas as pd
 
 from mitosheet.sheet_functions.types.utils import get_mito_type
