@@ -7,8 +7,9 @@ import json
 import uuid 
 from copy import copy, deepcopy
 import pandas as pd
-from typing import List
+from typing import List, Tuple
 
+from mitosheet.step_performers.import_steps.simple_import import SimpleImportStepPerformer
 from mitosheet.state import State
 from mitosheet.step import Step
 from mitosheet.step_performers import EVENT_TYPE_TO_STEP_PERFORMER
@@ -149,6 +150,26 @@ class StepsManager():
             )
         ]
 
+        """
+        To help with redo, we store a list of a list of the steps that 
+        existed in the step manager before the user clicked undo or reset,
+        along with the type of operation
+        
+        An example of what this object contains:
+        1.  The user passes a dataframe df1, adds column A to df1, imports df2, and then
+            adds B and C to df2. steps=[add A to df1, import df2, add B to df2, add C to df2]
+        2.  The user presses undo. Thus, steps=[add A to df1, import df2, add B to df2],
+            and undone_step_list_store = [('undo', [add C to df2])].
+        3.  The user then presses clear. Thus, steps = [import df2], and 
+            undone_step_list_store = [('undo', [add C to df2]), ('clear', [add A to df1, import df2, add B to df2])]
+        
+        Note that for a undo, we only store the last step that has been undone, but for a clear, 
+        we store the entire step list that we are replacing. This makes it possible
+        to easily undo the clear after it's done, as we have the proper step list
+        around.
+        """
+        self.undone_step_list_store: List[Tuple[str, List[Step]]] = []
+
         # We display the state that exists after the curr_step_idx is applied,
         # which means you can never see before the initalize step
         self.curr_step_idx = 0
@@ -321,6 +342,10 @@ class StepsManager():
 
         self.execute_and_update_steps(new_steps)
 
+        # If we add a new step, then we clear the last_undone_list_store, as
+        # you cannot redo something after you make a new edit
+        self.undone_step_list_store = []
+
     def handle_update_event(self, update_event):
         """
         Handles any event that isn't caused by an edit, but instead
@@ -377,16 +402,118 @@ class StepsManager():
             last_valid_index = min(newly_skipped_indexes.union({len(self.steps)})) - 1
         return last_valid_index
 
-    def execute_and_update_steps(self, new_steps: List[Step]):
+    def execute_undo(self):
+        """
+        This function attempts to undo the most recent step, and if there
+        is no most recent step, does nothing.
+
+        It also handles the special case where the last action was clearing
+        the analysis, in which case we have the undo actually reset the 
+        entire analysis.
+        """
+        
+        # When a user's most recent action is a clear analysis, then the undone_step_list_store
+        # will end in an item that says ('clear', [...]).
+        # In this case, if they press undo right after clearing, then we assume they probably 
+        # want to undo the clear, aka to redo all those steps
+        if len(self.undone_step_list_store) > 0:
+            if self.undone_step_list_store[-1][0] == 'clear':
+                return self.execute_redo()
+
+        # Otherwise, we just undo the most recent step that the user has created
+        # if they have created any steps
+        if len(self.steps) == 1:
+            return 
+
+        new_steps = copy(self.steps)
+        undone_step = new_steps.pop()
+
+        self.execute_and_update_steps(new_steps)
+
+        # If this works, then let's add this step to the undo list!
+        self.undone_step_list_store.append(
+            ('undo', [undone_step])
+        )
+
+    def execute_redo(self):
+        """
+        Executes a redo, which reapplies the most recently undone
+        steps if they exist.
+
+        This will not error if there is nothing to redo, it will
+        just return.
+        """
+        if len(self.undone_step_list_store) == 0:
+            return 
+        
+        (undo_or_clear, step_list) = self.undone_step_list_store[-1]
+        if undo_or_clear == 'undo':
+            # If it's an undo, just apply onto the end
+            new_steps = copy(self.steps)
+            new_steps.extend(step_list)
+            self.execute_and_update_steps(new_steps)
+
+        elif undo_or_clear == 'clear':
+            new_steps = step_list
+            # Note: since we're breaking the invariant that the steps don't
+            # move order, we have to execute from the very start
+            self.execute_and_update_steps(new_steps, last_valid_index=0)
+    
+        # Remove the item we just redid from the undone_step_list_store, so 
+        # that we don't redo it again
+        self.undone_step_list_store.pop()
+    
+
+    def execute_clear(self):
+        """
+        A clear update, which removes all steps in the analysis
+        that are not imports.    
+        """
+        if len(self.steps) == 1:
+            return 
+
+        # Keep only the initalize step and any import steps
+        new_steps = [
+            step for step in self.steps
+            if (
+                step.step_type == 'initialize' or \
+                step.step_type == SimpleImportStepPerformer.step_type()
+            )
+        ]
+
+        old_steps = copy(self.steps)
+
+        # We need to set the last_valid_index to 0 as we are changing
+        # the step order
+        self.execute_and_update_steps(new_steps, last_valid_index=0)
+
+        self.undone_step_list_store.append(
+            ('clear', old_steps)
+        )
+
+
+    def execute_and_update_steps(
+            self, 
+            new_steps: List[Step], 
+            last_valid_index=None
+        ):
         """
         Given a list of new_steps, runs them from the last valid index,
         based on what is skipped in these new_steps.
 
-        If these steps all result in valid execution, then we make them
-        the steps that the step manager stores. E.g. they become
-        the steps of the analysis.
+        If these new steps result in valid execution, then we set them
+        to the step that the step manager stores. 
+
+        If last_valid_index is passed, then this will be used instead of 
+        the last_valid_index that could be calculated by the step list.
+
+        So, pass a last_valid_index if you're changing the order of the steps
+        in the new_steps array. Otherwise, the step manager can calculate
+        the last valid index without help.
         """
-        last_valid_index = self.find_last_valid_index(new_steps)
+        if last_valid_index is None:
+            last_valid_index = self.find_last_valid_index(new_steps)
+        
         final_steps = execute_step_list_from_index(new_steps, start_index=last_valid_index)
         self.steps = final_steps
         self.curr_step_idx = len(self.steps) - 1
