@@ -82,6 +82,7 @@ class MitoWidgetTestWrapper:
 
     def merge_sheets(
             self, 
+            how,
             sheet_index_one, 
             merge_key_one, 
             selected_columns_one,
@@ -97,6 +98,7 @@ class MitoWidgetTestWrapper:
                 'type': 'merge_edit',
                 'step_id': get_new_id(),
                 'params': {
+                    'how': how,
                     'sheet_index_one': sheet_index_one,
                     'merge_key_one': merge_key_one,
                     'selected_columns_one': selected_columns_one,
@@ -299,6 +301,26 @@ class MitoWidgetTestWrapper:
             }
         )
     
+    def redo(self):
+        self.mito_widget.receive_message(
+            self.mito_widget,
+            {
+                'event': 'update_event',
+                'id': get_new_id(),
+                'type': 'redo'
+            }
+        )
+
+    def clear(self):
+        self.mito_widget.receive_message(
+            self.mito_widget,
+            {
+                'event': 'update_event',
+                'id': get_new_id(),
+                'type': 'clear'
+            }
+        )
+    
     def save_analysis(self, analysis_name):
         self.mito_widget.receive_message(
             self.mito_widget,
