@@ -10,14 +10,13 @@ container and generates transpiled Python code.
 """
 
 from mitosheet.preprocessing import PREPROCESS_STEPS
-from mitosheet.steps import STEP_TYPE_TO_STEP
 
 
 IN_PREVIOUS_STEP_COMMENT = '# You\'re viewing a previous step. Click fast forward in the Mitosheet above to see the full analysis.'
 
-def transpile(widget_state_container, add_comments=True):
+def transpile(steps_manager, add_comments=True):
     """
-    Transpiles the code from the current steps in the widget_state_container, 
+    Transpiles the code from the current steps in the steps_manager, 
     displaying up to the checked out step.
 
     If add_comments, then adds descriptive comments using the step 
@@ -28,34 +27,36 @@ def transpile(widget_state_container, add_comments=True):
 
     # First, we transpile all the preprocessing steps
     for PREPROCESS_STEP in PREPROCESS_STEPS:
-        preprocess_code = PREPROCESS_STEP['transpile'](widget_state_container)
+        preprocess_code = PREPROCESS_STEP['transpile'](steps_manager)
         if len(preprocess_code) > 0:
             code.extend(preprocess_code)
 
+    from mitosheet.steps_manager import get_step_indexes_to_skip
+    step_indexes_to_skip = get_step_indexes_to_skip(steps_manager.steps)
+
     # We only transpile up to the currently checked out step
-    for step_index, step in enumerate(widget_state_container.steps[:widget_state_container.curr_step_idx + 1]):
+    for step_index, step in enumerate(steps_manager.steps[:steps_manager.curr_step_idx + 1]):
+        # Skip the initalize step, or any step we should skip
+        if step.step_type == 'initialize' or step_index in step_indexes_to_skip:
+            continue
 
         # The total code for this step
         step_code = []
 
-        # The object that contains all the functions for the step
-        step_object = STEP_TYPE_TO_STEP[step['step_type']]
-
-        params = {key: value for key, value in step.items() if key in step_object['params']}
-
-        # NOTE: we add a comment if add_comment is True, but we do not add a comment
-        # to the initalize step (as it says nothing)
-        if add_comments and step_index > 0:
+        # NOTE: we add a comment if add_comment is True
+        if add_comments:
             step_code.append(
-                '# ' + step_object['describe'](
-                    **params,
-                    df_names=step['df_names']
+                '# ' + step.step_performer.describe(
+                    **step.params,
+                    df_names=step.df_names
                 )
             )
         
-        transpiled_code = step_object['transpile'](
-            step,
-            **params
+        transpiled_code = step.step_performer.transpile(
+            step.prev_state,
+            step.post_state,
+            step.execution_data,
+            **step.params
         )
         
         # Make sure we don't add comments for steps with no code
@@ -69,7 +70,7 @@ def transpile(widget_state_container, add_comments=True):
 
     # If we have a historical step checked out, then we add a comment letting
     # the user know this is the case
-    if widget_state_container.curr_step_idx != len(widget_state_container.steps) - 1:
+    if steps_manager.curr_step_idx != len(steps_manager.steps) - 1:
         code.append(IN_PREVIOUS_STEP_COMMENT)
 
     return {
